@@ -4,7 +4,12 @@ from .Components import Clock
 from .Components import PhysicalComponent
 
 from .Components import LangevinNoise
-from .Components import ArbitaryWave
+from .Components import (
+    ArbitaryWave,
+    StaticWave,
+    PulseWave,
+    AlternatingPulseWave
+)
 from .Components import ArbitaryWaveGenerator
 
 from .Components import Connection
@@ -15,7 +20,11 @@ from .SpecializedComponents import Laser
 from .SpecializedComponents import VariableOpticalAttenuator
 from .SpecializedComponents import AsymmetricMachZehnderInterferometer
 
-from .utils import display_class_instances_data
+from .utils import (
+    display_class_instances_data,
+    display_laser_field,
+    get_time_delay_phase_correction
+)
 
 __all__ = [
     "Clock",
@@ -23,6 +32,9 @@ __all__ = [
 
     "LangevinNoise",
     "ArbitaryWave",
+    "StaticWave",
+    "PulseWave",
+    "AlternatingPulseWave",
     "ArbitaryWaveGenerator",
     
     "Connection",
@@ -34,8 +46,10 @@ __all__ = [
     "AsymmetricMachZehnderInterferometer",
 
     "display_class_instances_data",
+    "display_laser_field",
+    "get_time_delay_phase_correction"
 ]
 
-__version__ = '0.0.6'
+__version__ = '0.0.8'
 __author__ = 'Anshurup Gupta'
 __description__ = 'A high-level, open-source Python library designed for the theoretical simulation of laser systems'
\ No newline at end of file
